Stan Math Library: stan/math/fwd/scal/fun/fma.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
fma.hpp File Reference
`#include <math.h>`
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/prim/scal/meta/return_type.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 , typename T3 >
fvar< typename stan::return_type< T1, T2, T3 >::type > | stan::math::fma (const fvar< T1 > &x1, const fvar< T2 > &x2, const fvar< T3 > &x3)
| The fused multiply-add operation (C99). More...
template<typename T1 , typename T2 , typename T3 >
fvar< typename stan::return_type< T1, T2, T3 >::type > | stan::math::fma (const T1 &x1, const fvar< T2 > &x2, const fvar< T3 > &x3)
| See all-var input signature for details on the function and derivatives. More...
template<typename T1 , typename T2 , typename T3 >
fvar< typename stan::return_type< T1, T2, T3 >::type > | stan::math::fma (const fvar< T1 > &x1, const T2 &x2, const fvar< T3 > &x3)
| See all-var input signature for details on the function and derivatives. More...
template<typename T1 , typename T2 , typename T3 >
fvar< typename stan::return_type< T1, T2, T3 >::type > | stan::math::fma (const fvar< T1 > &x1, const fvar< T2 > &x2, const T3 &x3)
| See all-var input signature for details on the function and derivatives. More...
template<typename T1 , typename T2 , typename T3 >
fvar< typename stan::return_type< T1, T2, T3 >::type > | stan::math::fma (const T1 &x1, const T2 &x2, const fvar< T3 > &x3)
| See all-var input signature for details on the function and derivatives. More...
template<typename T1 , typename T2 , typename T3 >
fvar< typename stan::return_type< T1, T2, T3 >::type > | stan::math::fma (const fvar< T1 > &x1, const T2 &x2, const T3 &x3)
| See all-var input signature for details on the function and derivatives. More...
template<typename T1 , typename T2 , typename T3 >
fvar< typename stan::return_type< T1, T2, T3 >::type > | stan::math::fma (const T1 &x1, const fvar< T2 > &x2, const T3 &x3)
| See all-var input signature for details on the function and derivatives. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.